@@ -4,8 +4,6 @@ use dionysos_provider_derive::*;
 use dionysos_consumer_derive::*;
 use std::sync::Arc;
 
-#[has_consumers_list]
-#[has_thread_handle]
 #[derive(FileProvider)]
 #[derive(FileConsumer)]
 #[derive(Default)]
@@ -14,6 +12,12 @@ pub struct FilenameScanner {
     patterns: Arc<Vec<regex::Regex>>,
 
     unsealed_patterns: Vec<regex::Regex>,
+
+    #[consumers_list]
+    consumers: Vec<Box<dyn FileConsumer>>,
+
+    #[thread_handle]
+    thread_handle: Option<std::thread::JoinHandle<()>>,
 }
 
 impl FilenameScanner {
