@@ -1,15 +1,14 @@
 use std::sync::Arc;
 use crate::consumer::*;
 use crate::scanner_result::ScannerResult;
-use dionysos_provider_derive::*;
 use dionysos_consumer_derive::*;
 
-#[has_consumers_list] // FIXME: this struct does not need a consumers list
-#[has_thread_handle]
 #[derive(FileConsumer)]
 #[derive(Default)]
-pub struct StdoutPrinter {}
-
+pub struct StdoutPrinter {
+    #[thread_handle]
+    thread_handle: Option<std::thread::JoinHandle<()>>,
+}
 
 impl FileHandler<()> for StdoutPrinter {
     fn handle_file(result: &ScannerResult, _: Arc<()>) {
