@@ -28,15 +28,19 @@ impl From<&yara::Rule<'_>> for YaraFinding {
     }
 }
 
-#[has_consumers_list]
-#[has_thread_handle]
 #[derive(FileProvider)]
 #[derive(FileConsumer)]
 #[derive(Default)]
 pub struct YaraScanner {
     #[consumer_data]
     data: Arc<Vec<yara::Rules>>,
-    unsealed_data: Vec<yara::Rules>
+    unsealed_data: Vec<yara::Rules>,
+
+    #[consumers_list]
+    consumers: Vec<Box<dyn FileConsumer>>,
+
+    #[thread_handle]
+    thread_handle: Option<std::thread::JoinHandle<()>>,
 }
 
 impl YaraScanner {
